% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% This program creates a Fuzzy Inference System (FIS) of Takagi-
% Sugeno-Kang (TSK) type for the data in Echavarria-Heras et al 2018.

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Numerical precision

  format longe
  
% Reading the data of the Echavarria-Heras et al. 2015

  load Echavarria_Heras_et_al_2018_Raw_data.txt
    
  A = [Echavarria_Heras_et_al_2018_Raw_data(:,1), Echavarria_Heras_et_al_2018_Raw_data(:,2)];
    
% Data

  X = A(:,1);
  Y = A(:,2);
    
% ********************************************
% Building the TSK fuzzy inference model
% ********************************************

  radii = 0.5416;  % Specifies a cluster center's range of influence
  
  fismat = gentskfistrain(X,Y,radii);
  
  if (isempty(fismat) == 1)
      return;
  end
  
  printprms('Mean Response Mean', fismat);
  
% ********************************************  
% Evaluate TSK MODEL FIS
% ********************************************

 [Yh,g,phi,alpha] = evaltskfis(X,fismat,'comp2gaussmf'); 
  
% ********************************************
% Mean Response Curve
% ********************************************  
  
  figure;
  plot(X,Y,'oblack', X,Yh,'-b');
  ylabel('y');
  xlabel('x') 
  legend('Observed','E_{aTSK}(y|x)');
  
% ********************************************  
% Reproducibility indeices
% ********************************************
  
  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(Y, Yh, 8);
  
  printdata('Table 8. Mean response curve',...
             AIC, CCC, R2, SEE, MPE, MPSE, radii, length(fismat.input.mf));

% ********************************************
% Residuals
% ********************************************
   
  ei = Y - Yh;
  
  figure; 
  plot(X,ei,'ob');
  xlabel('Fitted values');
  ylabel('Residuals');

% ********************************************
% Residuals qq-plot
% ********************************************

  figure;
  h = qqplot(Yh,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');
    
% ********************************************  
% Evaluate TSK MODEL FIS in continuos data
% ********************************************

  cX  = min(X):((max(X)-min(X))/10000):max(X);
  cX  = cX';

  [yp,g,phi,alpha] = evaltskfis(cX,fismat,'comp2gaussmf'); 

% ********************************************
% Membership functions
% ********************************************  
  
  figure; % Figure
  plotmf(fismat,'input',1,10000);
  ylabel('Grade of Membership');
  xlabel('x') 
  
