function y = comp1gaussmf(x, params)
% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ, UABC
% ENRIQUE VILLA DIHARCE
%
%   COMP1GAUSSMF composed Gaussian curve membership function.
%   COMP1GAUSSMF(x,PARAMS) returns a matrix which is the composed
%   Gaussian membership function evaluated at X. PARAMS is a 2-element vector
%   that determines the shape and position of this membership function.
%   Specifically, the formula for this membership function is:
%
%   COMP1GAUSSMF(X, [SIGMA, C]) = EXP(-(log(X) - C).^2/(2*SIGMA^2)));
%   
%   For example:
%
%       x = (0.1:0.1:5000)';
%       y1 = comp1gaussmf(x, [0.5 5]);
%       y2 = comp1gaussmf(x, [1 5]);
%       y3 = comp1gaussmf(x, [2 5]);
%       y4 = comp1gaussmf(x, [3 5]);
%       subplot(211); plot(x, [y1 y2 y3 y4]);
%       y1 = comp1gaussmf(x, [1 2]);
%       y2 = comp1gaussmf(x, [1 4]);
%       y3 = comp1gaussmf(x, [1 6]);
%       y4 = comp1gaussmf(x, [1 8]);
%       subplot(212); plot(x, [y1 y2 y3 y4]);
%       set(gcf, 'name', 'comp1gaussmf', 'numbertitle', 'off');
%

if nargin ~= 2
    error('Two arguments are required by the Composed Gaussian MF.');
elseif length(params) < 2
    error('The Composed Gaussian MF needs at least two parameters.');
elseif params(1) == 0,
    error('The Composed Gaussian MF needs a non-zero sigma.');
end

sigma = params(1); c = params(2);
y = exp(-(log(x) - c).^2/(2*sigma^2));
