function y = comp2gaussmf(x, params)
% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ, UABC
% ENRIQUE VILLA DIHARCE
%
%   COMP2GAUSSMF composide Gaussian curve membership function.
%   COMP2GAUSSMF(x,PARAMS) returns a matrix which is the composide
%   Gaussian membership function evaluated at X. PARAMS is a 2-element
%   vector that determines the shape and position of this membership
%   function. Specifically, the formula for this membership function is:
%
%   COMP2GAUSSMF(X, [SIGMA, C]) = (EXP(EXP(-(log(X) - C).^2/(2*SIGMA^2)))-1)/(EXP(1)-1);
%   
%   For example:
%
%       x = (0.1:0.1:5000)';
%       y1 = comp2gaussmf(x, [0.5 5]);
%       y2 = comp2gaussmf(x, [1 5]);
%       y3 = comp2gaussmf(x, [2 5]);
%       y4 = comp2gaussmf(x, [3 5]);
%       subplot(211); plot(x, [y1 y2 y3 y4]);
%       y1 = comp2gaussmf(x, [1 2]);
%       y2 = comp2gaussmf(x, [1 4]);
%       y3 = comp2gaussmf(x, [1 6]);
%       y4 = comp2gaussmf(x, [1 8]);
%       subplot(212); plot(x, [y1 y2 y3 y4]);
%       set(gcf, 'name', 'comp2gaussmf', 'numbertitle', 'off');
%

if nargin ~= 2
    error('Two arguments are required by the composide Gaussian MF.');
elseif length(params) < 2
    error('The composide Gaussian MF needs at least two parameters.');
elseif params(1) == 0,
    error('The composide Gaussian MF needs a non-zero sigma.');
end

sigma = params(1); c = params(2);
y = (exp(exp(-(log(x) - c).^2/(2*sigma^2)))-1)/(exp(1)-1);
