function theta = evaltskfisrlsconseq(Xin,Xout,fisEG,order,mftypeEA)
    % Evaluate a Sugeno-type high order FIS based RLS
    % Compute the High Order TSK equation parameters
    %
    % AUTHORS 
    % CECILIA LEAL RAMIREZ
    % HECTOR A ECHAVARRIA HERAS
    % JUAN RAMON CASTRO RODRIGUEZ, UABC
    % ENRIQUE VILLA DIHARCE
    %
    [numData,numInp] = size(Xin);
    numRule = length(fisEG.rule);
    if order ~= 0
        for p=1:numData
            sumMu(p) = 0.0;
            for i=1:numRule
                sigmas  = fisEG.input.mf(i).params(1);
                centers = fisEG.input.mf(i).params(2);
                muVals = evalmf(Xin(p),[sigmas centers],mftypeEA);            
                sumMu(p) = sumMu(p) + muVals;
                colNum = (i - 1)*(order*numInp + 1);        
                for j=1:numInp
                    for k=1:order
                        muMatrix(p,colNum + order*(j-1)+k) = (Xin(p,j).^k).*muVals;
                    end
                end
                muMatrix(p,colNum + order*numInp + 1) = muVals;
            end
            for j=1:(numRule * (order*numInp + 1))
                muMatrix(p,j) = muMatrix(p,j)/sumMu(p);
            end
            Xin_rls = muMatrix(p,:);
            Xout_rls = Xout(p,:);
            theta = rls(p,Xin_rls,Xout_rls);
        end
    else
        for p=1:numData
            sumMu(p) = 0.0;
            for i=1:numRule
                sigmas  = fisEG.input.mf(i).params(1);
                centers = fisEG.input.mf(i).params(2);
                muVals = evalmf(Xin(p),[sigmas centers],mftypeEA);            
                sumMu(p) = sumMu(p) + muVals;            
                muMatrix(p,i) = muVals;
            end
            for j=1:numRule
                muMatrix(p,j) = muMatrix(p,j)/sumMu(p);
            end
            Xin_rls = muMatrix(p,:);
            Xout_rls = Xout(p,:);
            theta = rls(p,Xin_rls,Xout_rls);
        end
    end
end

function params = rls(k,rlsdata,yout)
    % RLS algorithm
    persistent P theta
    a = rlsdata;
    y = yout;
    n_p_k = length(a);
    m = length(y);
    if (k == 1)
        theta = zeros(n_p_k,m); % theta
        P = 1e10*eye(n_p_k,n_p_k);
    end
    tmp1 = (P*a')*(a*P);
    tmp2 = 1+(a*P)*a';
    P = P -tmp1/tmp2;
    diff = y-a*theta;
    tmp3 = P*a';
    theta = theta + tmp3*diff;
    params = theta;
end
