    % AUTHORS 
    % CECILIA LEAL RAMIREZ
    % HECTOR A ECHAVARRIA HERAS
    % JUAN RAMON CASTRO RODRIGUEZ
    % ENRIQUE VILLA DIHARCE
    
function [ fismat ] = gentskfistrain(Xin,Xout,radii)
 
% Verify that the values of the input parameters (Xin, Xout, radii,
% trnOpt, dispOpt and mftypeEA are not invalid.

if((radii >1 ) || ( radii <= 0 ))
    fismat = [];
    fprintf('\n The radius value must be greater than 0 and less than 1 \n');
    return;
end
    
if( (isempty(Xin) == 1 ) || (isempty(Xout) == 1))
    fismat = [];
    fprintf('\n The Xin or Xout is empty \n')
    return;
end

    % Logarithmic transformation
    lnX = log(Xin);
    lnY = log(Xout);
    %
    % genfis2 generates a Sugeno (TSK)-type FIS structure using subtractive
    % clustering and requires separate sets of input and output data as input
    % arguments. genfis2 may be used to generate an initial FIS for anfis
    % training. genfis2 accomplishes this by extracting a set of rules that
    % models the data behavior. An important advantage of using a clustering
    % method to find rules is that the resultant rules are more tailored to the
    % input data than they are in a FIS generated without clustering. This
    % result reduces the problem of an excessive propagation of rules when
    % the input data has a high dimension.
    % 
    % The rule extraction method first uses the subclust function to determine
    % the number of rules and antecedent membership functions and then uses
    % linear least squares estimation to determine each rule's consequent
    % equations. This function returns an FIS structure that contains a set of
    % fuzzy rules to cover the feature space.
    %
    % The arguments for genfis2 are as follows:
    %
    % -	Xin is a matrix in which each row contains the input values of a data point. 
    % -	Xout is a matrix in which each row contains the output values of a data point. 
    % -	radii is a vector that specifies a cluster center's range of influence in each
    %    of the data dimensions, assuming the data falls within a unit hyperbox.
    %
    %     For example, if the data dimension is 3 (e.g., Xin has two columns
    %     and Xout has one column), radii = [0.5 0.4 0.3] specifies that the ranges
    %     of influence in the first, second, and third data dimensions (i.e., the
    %     first column of Xin, the second column of Xin, and the column of
    %     Xout) are 0.5, 0.4, and 0.3 times the width of the data space,
    %     respectively. If radii is a scalar value, then this scalar value is applied
    %     to all data dimensions, i.e., each cluster center has a spherical
    %     neighborhood of influence with the given radius.
    %
    fis = genfis2(lnX,lnY,radii);
    %
    % ANFIS*. Training routine for sugeno-type (TSK) fuzzy inference system.
    %
    % Syntax
    %
    % [fis, error, stepsize] = anfis(trnData, initFIS, trnOpt)
    %
    % Description
    %
    % anfis uses a hybrid learning algorithm to tune the parameters of a
    % Sugeno-type (TSK) Fuzzy Inference System (FIS). The algorithm uses a
    % combination of the Recursive Least Squares (RLS) estimator and gradient
    % descent with adaptive learning rate back-propagation methods to
    % model a training data set.

    % Inputs arguments for anfis are:
    %
    % trnData - Training data, specified as a matrix. For an FIS with N inputs,
    %                trnData has N+1 columns, where the first N columns contain
    %                input data and the final column contains output data.
    %
    % initFIS - FIS structure used to provide an initial set of membership
    %              functions for training.
    %
    % trnOpt - Training options, specified as a vector of scalars that represent
    %               the following settings:
    %
    %               trnOpt(1) - Training epoch number (default: 10)
    %               trnOpt(2) - Training error goal (default: 1e-10)
    %               trnOpt(3) - Initial step size (default: 0.01)
    %               trnOpt(4) - Step size decrease rate (default: 0.9)
    %               trnOpt(5) - Step size increase rate (default: 1.1)
    %
    % Output arguments for anfis are:
    %
    % fis - FIS structure whose parameters are tuned the training data,
    %        returned as a structure.
    %
    % error - Root mean squared training data errors at each epoch, returned
    %            as an array of scalars.
    %
    % stepsize - Step sizes at each training epoch, returned as an array of
    %                 scalars. If the error measure undergoes two consecutive
    %                 combinations of an increase followed by a decrease, then anfis
    %                 scales the step size by the decrease rate, trnOpt(4). If the error
    %                 measure undergoes four consecutive decreases, then anfis scales
    %                 the step size by the increase rate, trnOpt(5). [**in Sect 6.7.2 (pp. 156),
    %                 equation (6.61), figure 6.18]
    %
    % *Jang, J.-S. R., "ANFIS: Adaptive-Network-based Fuzzy Inference Systems",
    % IEEE Transactions on Systems, Man, and Cybernetics, Vol. 23, No. 3,
    % pp. 665-685, May 1993.
    %
    % **Jang, J.-S. R., Sun, C-T., and E. Mizutani. 1997. Neuro-fuzzy and
    % soft-computing. Upper Saddle River: Prentice-Hall.
    
     trnOpt = [100 1e-8 0.001 0.90 1.1]; % Training options
     dispOpt = [0 0 0 0]; % Specify information to display in the Command Window during training
     mftypeEA = 'comp2gaussmf';
  
    [fis,trnErr,stepSize] = anfis([lnX lnY],fis,trnOpt,dispOpt);
    %
    % Reading parameters from fis. sigmas, centers parameters of the
    % membership functions of the antecedents.
    [sigmas,centers,~] = fnngetm(fis);
    % Parameters of the linear functions of the consequents.
    [~,numInp] = size(Xin);
    [~,numOutp] = size(Xout);
    [numRule,~] = size(centers);
    theta = evaltskfisrlsconseq(Xin,Xout,fis,1,mftypeEA);    
    % Creating FIS matrix;
    theStr = sprintf('TSK%g%g',numInp,numOutp);
    fismat.name=theStr;
    % FIS type
    fismat.type = 'sugeno';
    % Inference operators for and, or, imp, agg, and defuzz
    fismat.andMethod = 'prod';
    fismat.orMethod = 'probor';
    fismat.impMethod = 'prod';
    fismat.aggMethod = 'max';
    fismat.defuzzMethod = 'wtaver';    
    % Set the input variable labels
    for i=1:numInp
        theStr = sprintf('in%g',i);
        fismat.input(i).name = theStr;
    end
    % Set the output variable labels
    for i=1:numOutp
        theStr = sprintf('out%g',i);
        fismat.output(i).name = theStr;
    end
    % Set the input variable ranges
    minX = min(Xin);
    maxX = max(Xin);
    ranges = [minX ; maxX]';
    for i=1:numInp
       fismat.input(i).range = ranges(i,:);
    end
    % Set the output variable ranges
    minX = min(Xout);
    maxX = max(Xout);
    ranges = [minX ; maxX]';
    for i=1:numOutp
       fismat.output(i).range = ranges(i,:);
    end
    % Set the input membership function labels
    for i=1:numInp
        for j=1:numRule    
            theStr = sprintf('in%gcluster%g',i,j);
            fismat.input(i).mf(j).name = theStr;
        end
    end    
    % Set the output membership function labels
    for i=1:numOutp
        for j=1:numRule       
            theStr = sprintf('out%gcluster%g',i,j);
            fismat.output(i).mf(j).name = theStr;
        end
    end   
    % Set the input membership function types
    for i=1:numInp 
       for j=1:numRule
          fismat.input(i).mf(j).type = mftypeEA;
       end   
    end    
    % Set the output membership function types
    for i=1:numOutp
       for j=1:numRule
          fismat.output(i).mf(j).type = 'linear';
       end   
    end    
    % Set the input membership function parameters
    for i=1:numInp
       for j=1:numRule
          fismat.input(i).mf(j).params = [sigmas(i) centers(j, i)];
       end
    end
    % Set the output membership function parameters
    for i=1:numOutp
       for j=1:numRule
          outParams = reshape(theta(:,i),numInp + 1,numRule);
          fismat.output(i).mf(j).params = outParams(:,j)';
       end
    end
    % Set the membership function pointers in the rule list
    colOfEnum = [1:numRule]';
    for j=1:numRule
       for i=1:numInp
          fismat.rule(j).antecedent(i)=colOfEnum(j);
       end
       for i=1:numOutp   
          fismat.rule(j).consequent(i) = colOfEnum(j);
       end       
      % Set the antecedent operators and rule weights in the rule    
       fismat.rule(j).weight=1;
       fismat.rule(j).connection=1;
    end
end
