% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% This program creates a Fuzzy Inference System (FIS) of Takagi-
% Sugeno-Kang (TSK) type for the data in Mascaro et al 2011

% Cleaning variables resident in the memory and screen

  clc
  clearvars;
  
% Numerical precision

  format longe

% Reading the data of the Mascaro et al. 2011

  load Mascaro_et_al_2011_Raw_data.txt
    
  A = [Mascaro_et_al_2011_Raw_data(:,1), Mascaro_et_al_2011_Raw_data(:,2)];
    
% Data

  X = A(:,1);
  Y = A(:,2);
  
% ********************************************  
% Building the TSK fuzzy inference model
% ********************************************
  
  radii = 0.52;  % Specifies a cluster center's range of influence
  
  fismat = gentskfistrain(X,Y,radii);
  
  if (isempty(fismat) == 1)
      return;
  end
  
  printprms('Mean Response Curve', fismat);
  
% ********************************************  
% Evaluate TSK MODEL FIS
% ********************************************
 
   [Yh,g,phi,alpha] = evaltskfis(X,fismat,'comp2gaussmf');
  
% ********************************************
% Mean Response Curve
% ********************************************  
  
  figure; 
  plot(X,Y,'oblack', X,Yh,'-b');
  ylabel('y');
  xlabel('x') 
  legend('Observed','E_{\ita\rmTSK}(\ity \rm| \itx\rm)');
  
% ********************************************  
% Reproducibility index
% ********************************************
  
  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(Y, Yh, 8);
  
  printdata('Table 9. Mean response curve',...
             AIC, CCC, R2, SEE, MPE, MPSE, radii, length(fismat.input.mf));

% ********************************************
% Residuals
% ********************************************
   
  ei = Y - Yh;
  
  figure; 
  plot(X,ei,'ob');
  xlabel('Fitted values');
  ylabel('Residuals');

% ********************************************
% Residuals qq-plot
% ********************************************

  figure;
  h = qqplot(Yh,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');

% ********************************************  
% Evaluate TSK MODEL FIS in continuos data
% ********************************************

  cX  = min(X):((max(X)-min(X))/10000):max(X);
  cX  = cX';
 
  [Yh,g,phi,alpha] = evaltskfis(cX,fismat,'comp2gaussmf');
  
% ********************************************
% Membership functions
% ********************************************  
  
  figure;
  hold on
  plotmf(fismat,'input',1,10000);
  ylabel('Grade of Membership');
  xlabel('x') 
