function [OUT,G,PHI,ALPHA] = evaltskfis(X,fisEG,mftypeEA)
% evaltskfis.m
%
% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ, UABC
% ENRIQUE VILLA DIHARCE
%
% Compute the output(s) of a type-1 TSK FLS (type-1 antecedents 
% and type-0 consequent) when the antecedent membership functions 
% are expgaussmf.
%
% center, sigma are rxn matrix denotes the mean and std of
% antecedent expgaussmf MFs (r rules, with n antecedent in each rule).
% theta is mxr(n+1) matrix, which denotes the coefficients of consequents.
% X is input matrix, qxn matrix, each row is on input.
%
[SIGMA,CENTER,THETA] = fnngetm(fisEG);
m = size(THETA,2);
[q,n] = size(X);
r = size(CENTER,1);
ALPHA = zeros(q,r);   % q x r
PHI   = zeros(q,r);   % q x r
G     = zeros(q,m*r); % q x mr
OUT   = zeros(q,m);   % q x m
for p=1:q % q data
    alpha=zeros(1,r);
    for k=1:r % r rules
        %
        alpha(k) = evalmf(X(p),[SIGMA(k) CENTER(k)],mftypeEA);
        %
    end
    ALPHA(p,:) = alpha;
    phi=alpha/sum(alpha);
    PHI(p,:) = phi;
    % Compute the consequent
    gg = zeros(1,m*r); % 1 x mr
    y = zeros(1,m);
    for j=1:m % m outputs
        C = reshape(THETA(:,j),n+1,r)'; % r x (n+1)
        g = zeros(1,r); % 1 x r
        for k=1:r% r rules
            g(k) = C(k,n+1);
            for i=1:n % n inputs
                g(k)=g(k)+C(k,i)*X(p,i);
            end
        end
        col1 = (j-1)*r+1;
        col2 = j*r;
        gg(col1:col2) = g; % 1 x mr
        y(1,j)=phi*g';
    end
    G(p,:) = gg;
    OUT(p,:) = y;
end
