% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% This program creates a Fuzzy Inference System (FIS) of Takagi-
% Sugeno-Kang (TSK) type for the data in Robertis and Williams 2018

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Reading the data set

  load DeRobertis_and_Williams_Raw_data.txt
    
  A = [DeRobertis_and_Williams_Raw_data(:,1), DeRobertis_and_Williams_Raw_data(:,2)];
    
% Data

  X = exp(A(:,1));
  Y = exp(A(:,2));
      
% ********************************************
% Building the TSK fuzzy inference model
% ********************************************  
  
  radii = 0.4;     % Specifies a cluster center's range of influence
  
  fismat = gentskfistrain(X,Y,radii);
  
  if (isempty(fismat) == 1)
      return;
  end
  
  printprms('Mean Response Curve', fismat);
  
% ********************************************
% Mean Response Curve
% ********************************************  
  
  [i,j] = sort(X);
  cX = i;
  cY = Y(j);
  
  [cYh,g,phi,alpha] = evaltskfis(cX,fismat,'comp2gaussmf'); 
 
  figure; 
  plot(X,Y,'oblack', cX,cYh,'ob');
  ylabel('y');
  xlabel('x') 
  legend('Observed','E_{aTSK}(y|x)');
  
% ********************************************  
% Reproducibility index
% ********************************************
  
  [Yh,g,phi,alpha] = evaltskfis(X,fismat,'comp2gaussmf'); 
  
  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(Y, Yh, 8);
  
  printdata('Table 11. Mean response curve',...
             AIC, CCC, R2, SEE, MPE, MPSE, radii, length(fismat.input.mf));

% ********************************************
% Residuals
% ********************************************
     
  ei = Y - Yh;
  
  figure; 
  plot(Yh,ei,'om');
  xlabel('Fitted values');
  ylabel('Residuals');

% ********************************************
% Residuals qq-plot
% ********************************************

  figure;
  h = qqplot(Yh,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');
  
% ********************************************  
% Evaluate TSK MODEL FIS in continuos data
% ********************************************

  cX  = min(X):((max(X)-min(X))/10000):max(X);
  cX  = cX';

  [yp,g,phi,alpha] = evaltskfis(cX,fismat,'comp2gaussmf'); 

% ********************************************
% Membership function
% ********************************************  
  
  figure;
  plotmf(fismat,'input',1,10000);
  ylabel('Grade of Membership');
  xlabel('x') 
  