% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% This program creates a Fuzzy Inference System (FIS) of 
% Takagi-Sugeno-Kang (TSK) type for the data in Huxley 1932.

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Reading the data set

  load Huxley_1932_raw_data.txt
    
  A = [Huxley_1932_raw_data(:,1), Huxley_1932_raw_data(:,2)];
    
% Data

  X = A(:,1);
  Y = A(:,2);
  
% Logarithmic transformation of the zostera data set

  lnX = log(X);
  lnY = log(Y);
  
% Ajuste de dos rectas

  xi = lnX(1:15);
  yi = lnY(1:15);
  
  xj = lnX(16:25);
  yj = lnY(16:25);
  
  a =       1.626;  %(1.595, 1.657)
  b =      -4.955;  %(-5.132, -4.778)

  f1 = a.*lnX+b;
  
  a =       1.274;  %(1.219, 1.329)
  b =      -2.621;  %(-3.015, -2.226) General model:
       
  f2 = a.*lnX+b;
  
  figure;
  hold on
  plot(lnX/2.3, lnY/2.3,'oblack', lnX/2.3, f1/2.3, '-r', lnX/2.3, f2/2.3, '-b');
  line([2.8744, 2.8744], [ 2.0, 3.0]);
  xlabel('u');
  ylabel('log(Body - Weight)');
  legend('Observed','y = b_{1H} + \alpha_{1H} x', 'y = b_{2H} + \alpha_{2H} x');
  hold off
  



