% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE
    
function [fismat] = gentskfis(Xin,Xout,radii)

% Verify that the values of the input parameters (Xin, Xout and radii)
% are not invalid.

if((radii >1 ) || ( radii <= 0 ))
    fismat = [];
    fprintf('\n The radius value must be greater than 0 and less than 1 \n');
    return;
end
    
if( (isempty(Xin) == 1 ) || (isempty(Xout) == 1))
    fismat = [];
    fprintf('\n The Xin or Xout is empty \n')
    return;
end

% genfis2 generates a Sugeno (TSK)-type FIS structure using subtractive
% clustering. 
% genfis2 may be used to generate an initial FIS for anfis training. 

% The arguments for genfis2 can be reviewed in the Matlab's Manual.
% However, we show them here:
%
% -	Xin is a matrix in which each row contains the input values of a data point. 
% -	Xout is a matrix in which each row contains the output values of a data point. 
% -	radii is a vector that specifies a cluster center's range of influence in each
%    of the data dimensions, assuming the data falls within a unit hyperbox.
%
% For example, if the data dimension is 3 (e.g., Xin has two columns
% and Xout has one column), radii = [0.5 0.4 0.3] specifies that the ranges
% of influence in the first, second, and third data dimensions (i.e., the
% first column of Xin, the second column of Xin, and the column of
% Xout) are 0.5, 0.4, and 0.3 times the width of the data space,
% respectively. If radii is a scalar value, then this scalar value is applied
% to all data dimensions, i.e., each cluster center has a spherical
% neighborhood of influence with the given radius.

  fismat = genfis2(Xin,Xout,radii);

% ANFIS*. Training routine for sugeno-type (TSK) fuzzy inference system.
%
% Syntax
%
% [fis, error, stepsize] = anfis(trnData, initFIS, trnOpt)
%
% Description
%
% anfis uses a hybrid learning algorithm to tune the parameters of a
% Sugeno-type (TSK) Fuzzy Inference System (FIS). The algorithm uses a
% combination of the Recursive Least Squares (RLS) estimator and gradient
% descent with adaptive learning rate back-propagation methods to
% model a training data set.

% Inputs arguments for anfis are:
%
% trnData - Training data, specified as a matrix. For an FIS with N inputs,
%                trnData has N+1 columns, where the first N columns contain
%                input data and the final column contains output data.
%
% initFIS - FIS structure used to provide an initial set of membership
%              functions for training.
%
% trnOpt - Training options, specified as a vector of scalars that represent
%               the following settings:
%
%               trnOpt(1) - Training epoch number (default: 10)
%               trnOpt(2) - Training error goal (default: 1e-10)
%               trnOpt(3) - Initial step size (default: 0.01)
%               trnOpt(4) - Step size decrease rate (default: 0.9)
%               trnOpt(5) - Step size increase rate (default: 1.1)
%
% Output arguments for anfis are:
%
% fis - FIS structure whose parameters are tuned the training data,
%        returned as a structure.
%
% error - Root mean squared training data errors at each epoch, returned
%            as an array of scalars.
%
% stepsize - Step sizes at each training epoch, returned as an array of
%                 scalars. If the error measure undergoes two consecutive
%                 combinations of an increase followed by a decrease, then anfis
%                 scales the step size by the decrease rate, trnOpt(4). If the error
%                 measure undergoes four consecutive decreases, then anfis scales
%                 the step size by the increase rate, trnOpt(5). [**in Sect 6.7.2 (pp. 156),
%                 equation (6.61), figure 6.18]
%
% Jang, J.-S. R., "ANFIS: Adaptive-Network-based Fuzzy Inference Systems",
% IEEE Transactions on Systems, Man, and Cybernetics, Vol. 23, No. 3,
% pp. 665-685, May 1993.
%
% **Jang, J.-S. R., Sun, C-T., and E. Mizutani. 1997. Neuro-fuzzy and
% soft-computing. Upper Saddle River: Prentice-Hall.

  if (length(fismat.rule) > 1) 
      
      % ANFIS do a more fine fitting.

      trnOpt = [100 1e-6 0.01 0.9 1.1];
  
      [fismat,trnErr,stepSize] = anfis([Xin Xout],fismat,trnOpt);
  end
end
  

    
    