% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% This program creates a Fuzzy Inference System (FIS) of 
% Takagi-Sugeno-Kang (TSK) type for the data in Robertis.

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Reading the data of the Robertis and Williams 2008

  load DeRobertis_and_Williams_Raw_data.txt
    
  A = [DeRobertis_and_Williams_Raw_data(:,1), DeRobertis_and_Williams_Raw_data(:,2)];
    
% Data

  lnX = A(:,1);
  lnY = A(:,2);
    
% ********************************************  
% Building the TSK - PLA fuzzy inference model
% ********************************************
   
  radii = 0.5;
  
  fismat = gentskfis(lnX, lnY, radii);
  
  if (isempty(fismat) == 1) 
      return;
  end
  
  printprms('Mean Response Curve', fismat);
  
% ********************************************  
% Evaluate TSK MODEL FIS
% ********************************************
 
  [lnYh,g,phi,alpha] = evaltskfis(lnX,fismat,'gaussmf');
     
% ********************************************
% Mean response curve
% ********************************************
      
  figure; 
  plot(lnX,lnY,'or', lnX, lnYh,'-b');
  ylabel('v_{TSK}(u,\pi)');
  xlabel('u'); 
  
% ********************************************  
% Reproducibility index
% ********************************************
  
% Aqui debe ir el punto de interseccion entre el cluster 1 y cluster 2

  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(lnY, lnYh, 8);
  
  printdata('Mean response curve',...
             AIC, CCC, R2, SEE, MPE, MPSE, radii, length(fismat.input.mf));

% ********************************************
% Residuals
% ********************************************
   
  ei = lnY - lnYh;
  
  figure;
  hold on
  plot(lnYh,ei,'ob');
  line([0 max(lnYh)],[0,0],'Color',[0.2 0.2 0.2]);
  xlabel('Fitted values');
  ylabel('Residuals');
  hold off
  
% ********************************************
% Residuals qq-plot
% ********************************************

  figure;
  h = qqplot(lnYh,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');
    
% ******************************************** 
% Back - Transformation - Mean response curve  
% ********************************************
  
  fc =  correction_factor_eq_56(lnY, lnYh, ei);
  
  figure; % Figure 15d
  plot(exp(lnX),exp(lnY),'oblack', exp(lnX), exp(lnYh)*fc,'om');
  ylabel('E_{gTSK}(y|x)');
  xlabel('x'); 
   
% ******************************************** 
% Back - Transformation - Mean response curve    
% Reproducibility indices
% ********************************************

  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(exp(lnY), exp(lnYh)*fc, 8);
  
  printdata('Table 11. Back - Transformation - Mean response curve',...
             AIC, CCC, R2, SEE, MPE, MPSE, radii, length(fismat.input.mf));
  
% ********************************************  
% Evaluate TSK MODEL FIS in continuous data
% ********************************************
 
  clnX  = min(lnX):((max(lnX)-min(lnX))/10000):max(lnX);
  clnX  = clnX';  
  
  [lnYh,g,phi,alpha] = evaltskfis(clnX,fismat,'gaussmf');
  
% ********************************************
% Membership functions
% ********************************************
    
  figure;
  hold on
  plotmf(fismat,'input',1,10000);
  ylabel('Grade of membership');
  xlabel('u') 
  hold off
  
