% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Reading the data set of DeRobertis and Williams (2008)
  
  load DeRobertis_and_Williams_Raw_data.txt
    
  A = [DeRobertis_and_Williams_Raw_data(:,1), DeRobertis_and_Williams_Raw_data(:,2)];
  
% Data set: Leaf area - Leaf biomass

  X = exp(A(:,1));
  Y = exp(A(:,2));
  
% Estimates obtained by fitting the linear model to
% Raw data of DeRobertis and Williams (2008) in R

  a =     0.01233;  %(0.01197, 0.01268)
  b =       2.851;  %(2.843, 2.858)

  printprms('Mean Response Curve', a, b)
  
% Data predicted

  Yp = a.*X.^b;

% Residuals
   
  ei = (Y - Yp);
  
% =============================================================
% Mean response curve
% =============================================================

% Data predicted

  [i,j] = sort(X);
  cX = i;
  cY = Y(j);
  
  Yh = a.*cX.^b;
  
% =============================================================
% Mean Response Curve
% =============================================================
  
  load brobpla.txt
  
  figure; % Figure 15d
  plot(X, Y, 'oblack', cX, Yh, 'ob', brobpla(:,1), brobpla(:,2), 'or');
  legend('Observed','\itw\rm_s(x|y)','E_{gTSK}(x|y)','Location','NW')
  xlabel('x');
  ylabel('y');
  title('d)');
  
% =============================================================
% Reproducbility indices
% =============================================================

  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(Y, Yp, 2);
  
  printdata('Mean Response Curve', AIC, CCC, R2, SEE, MPE, MPSE)
  
% =============================================================
% Residuals
% =============================================================

  figure; % Figure 15e
  hold on
  plot(Yp,ei,'bo');
  line([0 4000],[0,0],'Color',[0.3 0.3 0.3]);
  xlabel('Fitted values');
  ylabel('Residuals');
  title('e)');
  hold off
  
% =============================================================
% QQ-Plot
% =============================================================

  figure; % Figure 15f
  h = qqplot(Yp,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');
  title('f)')
  

  