% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Reading the data of the Echavarria-Heras et al. 2015
  
  load Echavarria_Heras_et_al_2018_Raw_data.txt
    
  A = [Echavarria_Heras_et_al_2018_Raw_data(:,1), Echavarria_Heras_et_al_2018_Raw_data(:,2)];
  
% Datos

  X = A(:,1);
  Y = A(:,2);
  
% Logarithmic transformation of the zostera data set

  lnX = log(X);
  lnY = log(Y);

% Data continuos

  clnX  = min(lnX):((max(lnX)-min(lnX))/50):max(lnX);
  clnX  = clnX';

% Estimates obtained by fitting the linear model to
% Raw data of the Echavarria_et_al_2018 in R

  p1 =       1.023;
  p2 =       -11.2;

  printprms('Table 1. Mean Response Curve', p1, p2);
    
% Data projected

  clnYp = p1.*clnX + p2;

  dlnYp = p1.*lnX + p2;
  
% Residuals
   
  ei = (lnY - dlnYp);

% ******************************************************************
% Mean Response Curve
% ******************************************************************

  figure; % Figure 2a
  hold on
  plot(lnX, lnY, 'oblack', clnX, clnYp, '-b');
  xlabel('log (Area) (mm^2)');
  ylabel('log (Biomass) (kg)');
  legend('Observed','\itv\rm_s(u,\pi)','Location','NW')
  title('Figure 2a');
  hold off

% ****************************************************************** 
% Residuals
% ******************************************************************

  figure; % Figure 2b
  hold on
  plot(dlnYp,ei,'bo');
  line([-11,-1],[0,0],'Color',[0.5 0.5 0.5]);
  xlabel('Fitted values');
  ylabel('Residuals');
  title('Figure 2b');
  hold off

% ******************************************************************
% Residuals QQ-plot
% ******************************************************************

  figure; % Figure 2c
  h = qqplot(dlnYp,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');
  title('Figure 2c')
  
% ******************************************************************  
% Reproducibility indices
% ******************************************************************

  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(lnY, dlnYp, 2);
  
  printdata('Table 4. Mean Response Curve', AIC, CCC, R2, SEE, MPE, MPSE);
  

