% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Reading the data set of Huxley 1932
  
  load Huxley_1932_Raw_data.txt
    
  A = [Huxley_1932_Raw_data(:,1), Huxley_1932_Raw_data(:,2)];
  
% Data set: Leaf area - Leaf biomass

  X = A(:,1);
  Y = A(:,2);
  
% Logarithmic transformation of the data set

  lnX = log(X);
  lnY = log(Y);

% Data continuos

  clnX  = min(lnX):((max(lnX)-min(lnX))/100):max(lnX);
  clnX  = clnX';

% Estimates obtained by fitting the linear model to
% Raw data of Huxley 1932

  p1 =      1.542;
  p2 =     -4.507;

  printprms('Mean Response Curve', p1, p2)
  
% Data predicted

  clnYp = p1.*clnX + p2;

  dlnYp = p1.*lnX + p2;
  
% Residuals
   
  ei = (lnY - dlnYp);
  
% Standar desviation  
 
  sigma = std(ei);
  
% =============================================================
% Mean Response Curve
% =============================================================

  figure; % Figure 9d
  plot(lnX, lnY, 'or', clnX, clnYp, '-b');
  %line([2.9*2.3, 2.9*2.3], [2*2.3, 3*2.3], 'Color', [0.2 0.2 0.2]);
  legend('Observed','\itv\rm_s(u,\pi)','Location','NW')
  xlabel('log (Chela - weight) (cm)');
  ylabel('log (Body - weight) (kg)');
  title('Figure 9d');
  
% ************************************************  
% Residuals
% ************************************************

  figure; % Figure 9e
  hold on
  plot(dlnYp,ei,'bo');
  line([0 8],[0,0],'Color',[0.3 0.3 0.3]);
  xlabel('Fitted values');
  ylabel('Residuals');
  title('Figure 9e');
  hold off
  
% ************************************************
% Residuals QQ-plot
% ************************************************

  figure; % Figure 9f
  h = qqplot(dlnYp,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');
  title('Figure 9f)')
  
% ************************************************  
% Reproducbility indices
% ************************************************

  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(lnY, dlnYp, 2);
  
  printdata('Table 6. Mean Response Curve', AIC, CCC, R2, SEE, MPE, MPSE);
  