% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Reading the data of the Mascaro et al. 2012
  
  load Mascaro_et_al_2011_Raw_data.txt
    
  A = [Mascaro_et_al_2011_Raw_data(:,1), Mascaro_et_al_2011_Raw_data(:,2)];
  
% Datos

  X = A(:,1);
  Y = A(:,2);
  
% Logarithm transformation

  lnX = log(X);
  lnY = log(Y);
  
% Estimates obtained by fitting the non linear model to
% Raw data of the Mascaro et al 2011

  a =       2.091;  %(1.914, 2.268)
  b =      -1.211;  %(-1.555, -0.8673)
  
  printprms('Mean Response Curve', a, b);
  
% Data projected

  Yp = a.*lnX + b;
  
% Residuals
   
  ei = (lnY - Yp);
  
% ******************************************************************
% Mean Response Curve
% ******************************************************************

  figure; % Figure 7d
  hold on
  plot(lnX, lnY, 'oblack', lnX, Yp, 'ob');
  xlabel('Diameter');
  ylabel('Aboveground Biomass');
  legend('Observed','\itw\rm_s(\itx,\theta\rm)','Location','NW');
  title('Figure 7d')
  hold off

% ****************************************************************** 
% Residuals
% ******************************************************************

  figure; % Figure 7e
  hold on
  plot(Yp,ei,'bo');
  line([min(Yp),max(Yp)],[0,0],'Color',[0.5 0.5 0.5]);
  xlabel('Fitted values');
  ylabel('Residuals');
  title('Figure 7e');
  hold off

% ******************************************************************
% Residuals QQ-plot
% ******************************************************************

  figure; % Figure 7f
  h = qqplot(Yp,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');
  title('Figure 7f')
  
% ******************************************************************
% Reproducibility index
% ******************************************************************

  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(lnY, Yp, 2);
  
  printdata('Table 5. Mean Response Curve', AIC, CCC, R2, SEE, MPE, MPSE);