% AUTHORS 
% CECILIA LEAL RAMIREZ
% HECTOR A ECHAVARRIA HERAS
% JUAN RAMON CASTRO RODRIGUEZ
% ENRIQUE VILLA DIHARCE

% Cleaning variables resident in the memory and screen

  clc
  clearvars;

% Reading the data set of DeRobertis and Williams (2008)
  
  load DeRobertis_and_Williams_Raw_data.txt
    
  A = [DeRobertis_and_Williams_Raw_data(:,1), DeRobertis_and_Williams_Raw_data(:,2)];
  
% Data set: Leaf area - Leaf biomass

  lnX = A(:,1);
  lnY = A(:,2);
  
% Data continuos

  clnX  = min(lnX):((max(lnX)-min(lnX))/50):max(lnX);
  clnX  = clnX';

% Estimates obtained by fitting the linear model to
% Raw data of DeRobertis and Williams (2008) in R

  p1 =    2.931;
  p2 =   -4.7; 
  
  printprms('Mean Response Curve', p1, p2)
  
% Data predicted

  clnYp = p1.*clnX + p2;

  dlnYp = p1.*lnX + p2;
  
% Residuals
   
  ei = (lnY - dlnYp);
  
% Standar desviation  
 
  sigma = std(ei);
  
% =============================================================
% Mean Response Curve
% =============================================================

  figure; % Figure 11a
  plot(lnX, lnY, 'or', clnX, clnYp, '-b');
  legend('Observed','\itv\rm_s(u,\pi)','Location','NW')
  xlabel('log (Length) (cm)');
  ylabel('log (Weigth) (kg)');
  title('Figure 11a');
  
% =============================================================  
% Residuals
% =============================================================  

  figure; % Figure 11b
  hold on
  plot(dlnYp,ei,'bo');
  line([min(dlnYp), max(dlnYp)],[0,0],'Color',[0.3 0.3 0.3]);
  xlabel('Fitted values');
  ylabel('Residuals');
  title('Figure 11b');
  hold off

% =============================================================  
% Residuals qq-plot
% =============================================================  

  figure; % Figure 11c
  h = qqplot(dlnYp,ei);
  xlabel('Theoretical Quantiles');
  ylabel('Sample Quantiles');
  title('Figure 11c')
  
% =============================================================    
% Reproducbility indices
% =============================================================  

  [AIC, CCC, R2, SEE, MPE, MPSE] = findices(lnY, dlnYp, 2);
  
  printdata('Table 7. Mean Rsponse Curve', AIC, CCC, R2, SEE, MPE, MPSE);
  
  